Function reference
==================

EEG processing
--------------

.. autosummary::
   :toctree: generated

   pipeline.group_pipeline
   pipeline.participant_pipeline

Sample datasets
---------------

.. autosummary::
   :toctree: generated

   pipeline.datasets.get_erpcore
   pipeline.datasets.get_ucap
